==> spammaster-8.x-1.0-rc32.tar.gz: spammaster/src/Plugin/Block/SpamMasterTotalCountBlock.php <==
<?php

namespace Drupal\spammaster\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides 'Total Threats Count' Block.
 *
 * @Block(
 *   id = "total_threats_count_block",
 *   admin_label = @Translation("Spam Master Total Threats Count"),
 * )
 */
class SpamMasterTotalCountBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $configFactory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    $config = $this->getConfiguration();
    // Get Total Threats Count from module settings.
    $spammaster_settings = $this->configFactory->getEditable('spammaster.settings');
    $spammaster_total_threats_count = number_format($spammaster_settings->get('spammaster.license_protection'));

    return [
      '#theme' => 'total_count',
      '#type' => 'block',
      '#attached' => [
        'library' => [
          'spammaster/spammaster-styles',
        ],
      ],
      '#spammaster_total_threats_count' => $spammaster_total_threats_count,
      '#spammaster_total_threats_footer' => $this->t('by <a href="@spammaster_url">Spam Master</a>.', ['@spammaster_url' => 'https://spammaster.techgasp.com/']),
    ];

  }

}

==> spammaster-8.x-1.62.tar.gz: spammaster/src/Plugin/Block/SpamMasterTotalCountBlock.php <==
<?php

namespace Drupal\spammaster\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\State\StateInterface;

/**
 * Provides 'Total Threats Count' Block.
 *
 * @Block(
 *   id = "total_threats_count_block",
 *   admin_label = @Translation("Spam Master Total Threats Count"),
 * )
 */
class SpamMasterTotalCountBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, StateInterface $state) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('state')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    // Get Total Threats Count from module settings.
    $spammaster_total_threats_count = number_format($this->state->get('spammaster.license_protection'));

    return [
      '#theme' => 'total_count',
      '#type' => 'block',
      '#attached' => [
        'library' => [
          'spammaster/spammaster-styles',
        ],
      ],
      '#spammaster_total_threats_count' => $spammaster_total_threats_count,
      '#spammaster_total_threats_footer' => $this->t('by <a href="@spammaster_url">Spam Master</a>.', ['@spammaster_url' => 'https://spammaster.techgasp.com/']),
    ];

  }

}
